@@ -34,6 +34,14 @@ class TaskExecutor(metaclass=abc.ABCMeta):
         """
         pass
 
+    @abc.abstractmethod
+    def reconcile(self, task_config):
+        """Request a status event for a task
+
+        :param task_config: The task that you want to check
+        """
+        pass
+
     @abc.abstractmethod
     def kill(self, task_id):
         """Kill the specified task
