@@ -16,6 +16,9 @@ class Sync(Runner):
     def kill(self, task_id):
         self.executor.kill(task_id)
 
+    def reconcile(self, task_config):
+        self.executor.reconcile(task_config)
+
     def run(self, task_config):
         self.executor.run(task_config)
         event_queue = self.executor.get_event_queue()
